#######################################################################################################################################################################################################
#
# Changes to this type
# General
#     2022-Feb-01: add abstract type for vulnerability curve
#     2022-Feb-01: add documentation
#     2022-Apr-20: rename type to AbstractXylemVC
#
#######################################################################################################################################################################################################
"""

$(TYPEDEF)

Hierarchy of AbstractXylemVC:
- [`LogisticVC`](@ref)
- [`PowerVC`](@ref)
- [`WeibullVC`](@ref)
- [`ComplexVC`](@ref)
"""
abstract type AbstractXylemVC{FT<:AbstractFloat} end


#######################################################################################################################################################################################################
#
# Changes to this struct
# General
#     2022-Feb-01: add LogisticVC (use mutable so as to fit)
#     2022-Feb-01: add documentation
#
#######################################################################################################################################################################################################
"""

$(TYPEDEF)

Modified logistic function for vulnerability curve

# Fields

$(TYPEDFIELDS)

"""
mutable struct LogisticVC{FT<:AbstractFloat} <: AbstractXylemVC{FT}
    "Multiplier to exponential component"
    A::FT
    "Multiplier to pressure `[MPa⁻¹]`"
    B::FT
end


#######################################################################################################################################################################################################
#
# Changes to this struct
# General
#     2022-Feb-01: add PowerVC (use mutable so as to fit)
#     2022-Feb-01: add documentation
#
#######################################################################################################################################################################################################
"""

$(TYPEDEF)

Power function for vulnerability curve

# Fields

$(TYPEDFIELDS)

"""
mutable struct PowerVC{FT<:AbstractFloat} <: AbstractXylemVC{FT}
    "Multiplier to power component `[MPa⁻ᵇ]`"
    A::FT
    "Power to pressure"
    B::FT
end


#######################################################################################################################################################################################################
#
# Changes to this struct
# General
#     2022-Feb-01: add WeibullVC (use mutable so as to fit)
#     2022-Feb-01: add documentation
#
#######################################################################################################################################################################################################
"""

$(TYPEDEF)

Weibull cumulative distribution function for vulnerability curve

# Fields

$(TYPEDFIELDS)

"""
mutable struct WeibullVC{FT<:AbstractFloat} <: AbstractXylemVC{FT}
    "Numerator in the exponential component `[MPa]`"
    B::FT
    "Power to pressure component"
    C::FT
end


#######################################################################################################################################################################################################
#
# Changes to this struct
# General
#     2022-Feb-01: add ComplexVC (use mutable so as to fit)
#     2022-Feb-01: add documentation
#
#######################################################################################################################################################################################################
"""

$(TYPEDEF)

A complex struct for segmented vulnerability curve such as dual Weibull function

# Fields

$(TYPEDFIELDS)

"""
mutable struct ComplexVC{FT} <: AbstractXylemVC{FT}
    "Percentages of each VC component"
    PS::Vector{FT}
    "Vector of vulnerability curve components"
    VCS::Union{Vector{LogisticVC{FT}}, Vector{PowerVC{FT}}, Vector{WeibullVC{FT}}, Vector{AbstractXylemVC{FT}}}
end
